Sprite

Struct Sprite 

pub struct Sprite<'a> { /* private fields */ }
A 1-bps or 2-bps bitmap drawable on screen

Sprites

WASM-4 natively supports sprites with the functions wasm4fun_core::blit and wasm4fun_core::blit_sub. Instead of passing sprite information as separate arguments, this structure conveniently wraps them in a single place. It also makes it easier to apply transformations using a SpriteViewImpl.

They can be generated by PNG images with the command w4 png2src --rust.

use wasm4fun_graphics::Sprite;

const CAR_WIDTH: u32 = 16;
const CAR_HEIGHT: u32 = 16;
const CAR_FLAGS: u32 = 1; // BLIT_2BPP
const CAR: [u8; 256] = [0; 256];

let car = Sprite::new(CAR_WIDTH, CAR_HEIGHT, CAR_FLAGS, &CAR);

// Draw car to screen
car.blit(10, 40);

// Create a clipped view of the original sprite
let clip = car.clip(0, 0, 8, 8);
clip.blit(10, 40);

Implementations

Source

impl<'a> Sprite<'a>

pub const fn new(width: u32, height: u32, flags: u32, data: &'a [u8]) -> Self

Create a new sprite

pub const fn width(&self) -> u32

Get the sprite width

pub const fn height(&self) -> u32

Get the sprite height

pub const fn rotate(&self, rotation: Rotation) -> SpriteViewImpl<'_>

Apply a rotation to the sprite

pub fn flip_horizontally(&self, flip_horizontally: bool) -> SpriteViewImpl<'_>

Flip the sprite horizontally

pub const fn flip_vertically(&self, flip_vertically: bool) -> SpriteViewImpl<'_>

Flip the sprite vertically

pub const fn clip( &self, src_x: u32, src_y: u32, width: u32, height: u32, ) -> SpriteViewImpl<'_>

Clip the sprite to a subregion

pub fn blit(&self, x: i32, y: i32)

Draw the sprite to the screen

The sprite is drawn at the point x, y.