SpriteViewImpl

Struct SpriteViewImpl 

pub struct SpriteViewImpl<'a> { /* private fields */ }
A view of a modified sprite

A sprite view can be used to apply transformations to a sprite before drawing it to screen.

use wasm4fun_graphics::{Rotation, Sprite};

let sprite: Sprite = unimplemented!();
let clipped = sprite.clip(30, 10, 80, 20);
let rotated = sprite.rotate(Rotation::Rotate90);
let clipped_and_rotated = clipped.rotate(Rotation::Rotate90);
rotated.blit(0, 0);
clipped_and_rotated.blit(50, 50);

Order of Operations

When applying both flipping and rotation, flipping is performed first.

Implementations

Source

impl<'a> SpriteViewImpl<'a>

pub const fn new(sprite: &'a Sprite<'_>) -> Self

Create a view over a sprite

pub const fn width(&self) -> u32

Get the sprite width

pub const fn height(&self) -> u32

Get the sprite height

pub const fn rotate(&self, rotation: Rotation) -> Self

Apply a rotation to the sprite view

pub const fn flip_horizontally(&self, flip_horizontally: bool) -> Self

Flip the sprite view horizontally

pub const fn flip_vertically(&self, flip_vertically: bool) -> Self

Flip the sprite view vertically

pub const fn clip( &self, src_x: u32, src_y: u32, width: u32, height: u32, ) -> Self

Clip the sprite view to a subregion

pub fn blit(&self, x: i32, y: i32)

Draw the sprite view to the screen

The sprite is drawn at the point x, y after applying all the transformations in the view.