pub struct SpriteViewImpl<'a> { /* private fields */ }Expand description
A view of a modified sprite
A sprite view can be used to apply transformations to a sprite before drawing it to screen.
use wasm4fun_graphics::{Rotation, Sprite};
let sprite: Sprite = unimplemented!();
let clipped = sprite.clip(30, 10, 80, 20);
let rotated = sprite.rotate(Rotation::Rotate90);
let clipped_and_rotated = clipped.rotate(Rotation::Rotate90);
rotated.blit(0, 0);
clipped_and_rotated.blit(50, 50);Order of Operations
When applying both flipping and rotation, flipping is performed first.
Implementations
Sourceimpl<'a> SpriteViewImpl<'a>
impl<'a> SpriteViewImpl<'a>
Sourcepub const fn flip_horizontally(&self, flip_horizontally: bool) -> Self
pub const fn flip_horizontally(&self, flip_horizontally: bool) -> Self
Flip the sprite view horizontally
Sourcepub const fn flip_vertically(&self, flip_vertically: bool) -> Self
pub const fn flip_vertically(&self, flip_vertically: bool) -> Self
Flip the sprite view vertically